import React, { useState, useEffect } from 'react';
import Head from 'next/head';
import { NextPage } from 'next';
import Layout from '@/components/Layout';
import ProductCard from '@/components/product/ProductCard';
import ProductSlider from '@/components/product/ProductSlider';
import HomeHero from '@/components/home/HomeHero';
import CategoryGrid from '@/components/category/CategoryGrid';
import FeaturedSection from '@/components/home/FeaturedSection';
import { get } from '@/lib/api-client';
import useDeviceDetect from '@/hooks/useDeviceDetect';
import { Product, Category } from '@/types/models';
import { FaSpinner } from 'react-icons/fa';
import Meta from '@/components/common/Meta';
import styles from '@/styles/pages/Home.module.scss';
import { ProductCardSkeleton } from '@/components/SkeletonLoader';
import OrganizationSchema from '@/components/schemas/OrganizationSchema';

const Home: NextPage = () => {
  const [featuredProducts, setFeaturedProducts] = useState<Product[]>([]);
  const [categories, setCategories] = useState<Category[]>([]);
  const [newArrivals, setNewArrivals] = useState<Product[]>([]);
  const [loading, setLoading] = useState(true);
  const { isLowEnd, isMobile } = useDeviceDetect();
  
  useEffect(() => {
    async function fetchData() {
      try {
        setLoading(true);
        
        // Parallel API requests
        const [
          featuredResponse,
          categoriesResponse,
          newArrivalsResponse
        ] = await Promise.all([
          get<Product[]>('/api/products/featured?limit=6'),
          get<Category[]>('/api/categories'),
          get<Product[]>('/api/products/new?limit=8')
        ]);
        
        if (featuredResponse.success) {
          setFeaturedProducts(featuredResponse.data || []);
        }
        
        if (categoriesResponse.success) {
          setCategories(categoriesResponse.data || []);
        }
        
        if (newArrivalsResponse.success) {
          setNewArrivals(newArrivalsResponse.data || []);
        }
      } catch (error) {
        console.error('Error fetching home data:', error);
      } finally {
        setLoading(false);
      }
    }
    
    fetchData();
  }, []);
  
  // Limit data on low-end devices
  const optimizedCategories = isLowEnd ? categories.slice(0, 4) : categories;
  
  return (
    <Layout>
      <Meta 
        title="Tài khoản Premium chất lượng cao"
        description="Cung cấp tài khoản Premium chất lượng cao cho các dịch vụ streaming, học tập và làm việc với giá tốt nhất và bảo hành trọn đời."
        ogImage="/images/home-og-image.jpg"
      />
      
      <OrganizationSchema />
      
      {/* Hero section with key message and main CTAs */}
      <HomeHero />
      
      {/* Featured Categories */}
      <section className={styles.categoriesSection}>
        <div className="container">
          <h2 className={styles.sectionTitle}>Khám phá dịch vụ</h2>
          
          {loading ? (
            <div className={styles.categorySkeletons}>
              {[...Array(4)].map((_, i) => (
                <div key={i} className={styles.categorySkeleton} />
              ))}
            </div>
          ) : (
            <CategoryGrid 
              categories={optimizedCategories} 
              columns={isMobile ? 2 : 4} 
            />
          )}
        </div>
      </section>
      
      {/* Featured Products */}
      <FeaturedSection 
        title="Sản phẩm nổi bật"
        products={featuredProducts}
        loading={loading}
      />
      
      {/* New Arrivals */}
      <section className={styles.newArrivalsSection}>
        <div className="container">
          <h2 className={styles.sectionTitle}>Sản phẩm mới</h2>
          
          {loading ? (
            <div className={styles.productsGrid}>
              {[...Array(isLowEnd ? 4 : 8)].map((_, i) => (
                <ProductCardSkeleton key={i} />
              ))}
            </div>
          ) : (
            <div className={styles.productsGrid}>
              {newArrivals.map((product) => (
                <ProductCard 
                  key={product._id} 
                  product={product}
                  priority={false}
                />
              ))}
            </div>
          )}
        </div>
      </section>
      
      {/* Why Choose Us Section */}
      <section className={styles.whyChooseUs}>
        <div className="container">
          <h2 className={styles.sectionTitle}>Tại sao chọn Premium Shop?</h2>
          
          <div className={styles.benefitsGrid}>
            <div className={styles.benefitCard}>
              <div className={styles.benefitIcon}>
                <img 
                  src="/icons/warranty.svg" 
                  alt="" 
                  width={48} 
                  height={48} 
                  aria-hidden="true"
                  loading="lazy"
                />
              </div>
              <h3>Bảo hành trọn đời</h3>
              <p>Cam kết hỗ trợ tài khoản của bạn trong suốt thời gian sử dụng.</p>
            </div>
            
            <div className={styles.benefitCard}>
              <div className={styles.benefitIcon}>
                <img 
                  src="/icons/support.svg" 
                  alt="" 
                  width={48} 
                  height={48} 
                  aria-hidden="true"
                  loading="lazy"
                />
              </div>
              <h3>Hỗ trợ 24/7</h3>
              <p>Đội ngũ hỗ trợ khách hàng luôn sẵn sàng giúp bạn mọi lúc.</p>
            </div>
            
            <div className={styles.benefitCard}>
              <div className={styles.benefitIcon}>
                <img 
                  src="/icons/secure.svg" 
                  alt="" 
                  width={48} 
                  height={48} 
                  aria-hidden="true"
                  loading="lazy"
                />
              </div>
              <h3>Thanh toán an toàn</h3>
              <p>Nhiều phương thức thanh toán an toàn và bảo mật tối đa.</p>
            </div>
            
            <div className={styles.benefitCard}>
              <div className={styles.benefitIcon}>
                <img 
                  src="/icons/delivery.svg" 
                  alt="" 
                  width={48} 
                  height={48} 
                  aria-hidden="true"
                  loading="lazy"
                />
              </div>
              <h3>Giao hàng nhanh chóng</h3>
              <p>Tài khoản được gửi tự động ngay sau khi thanh toán thành công.</p>
            </div>
          </div>
        </div>
      </section>
    </Layout>
  );
};

export default Home;